import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.*;

public class aerodynamics_mb {
    public static void main(String[] args) throws FileNotFoundException {
        new aerodynamics_mb().run();
    }

    final static int ZMIN = -1;
    final static int ZMAX = 101;
    final static double EPSILON = 1e-9;

    class Point3d {
        public final int x;
        public final int y;
        public final int z;

        Point3d(int x, int y, int z) {
            this.x = x;
            this.y = y;
            this.z = z;
        }
    }

    class Candidate2d {
        private final double x;
        private final double y;
        public final Edge edge;
        public boolean used;

        public Candidate2d(double x, double y, Edge edge) {
            this.x = x;
            this.y = y;
            this.edge = edge;
        }
    }

    class Edge {
        public final Point3d p1;
        public final Point3d p2;
        public boolean isActive;
        public Edge nextActiveEdge;
        public Edge prevActiveEdge;

        public Edge(Point3d p1, Point3d p2) {
            this.p2 = p2;
            this.p1 = p1;
        }
    }

    private Point3d[] points;
    private final LinkedList<Edge> edges = new LinkedList<Edge>();
    private final ArrayList<Edge>[] startLists = new ArrayList[ZMAX - ZMIN + 1];
    private final ArrayList<Edge>[] endLists = new ArrayList[ZMAX - ZMIN + 1];
    private final ArrayList<Candidate2d> candidates = new ArrayList<Candidate2d>();
    private Edge firstActiveEdge;

    private void populateEdges() {
        for (int z = 0; z < ZMAX - ZMIN + 1; z++) {
            startLists[z] = new ArrayList<Edge>();
            endLists[z] = new ArrayList<Edge>();
        }
        for (int i = 0; i < points.length; i++) {
            for (int j = i + 1; j < points.length; j++) {
                if (points[i].z != points[j].z) {
                    int zstart = Math.max(Math.min(points[i].z, points[j].z) + 1, ZMIN);
                    int zend = Math.min(Math.max(points[i].z, points[j].z) - 1, ZMAX);
                    if (zstart <= zend && zstart <= ZMAX && zend >= ZMIN ) {
                        Edge edge = new Edge(points[i], points[j]);
                        startLists[zstart - ZMIN].add(edge);
                        endLists[zend - ZMIN].add(edge);
                    }
                }
            }
        }
    }

    private void addToActiveEdges(Edge edge) {
        if (edge.isActive) {
            return;
        }
        edge.isActive = true;
        edge.nextActiveEdge = firstActiveEdge;
        if (firstActiveEdge != null) {
            firstActiveEdge.prevActiveEdge = edge;
        }
        firstActiveEdge = edge;
    }

    private void removeFromActiveEdges(Edge edge) {
        if (!edge.isActive) {
            return;
        }
        edge.isActive = false;
        if (edge.nextActiveEdge != null) {
            edge.nextActiveEdge.prevActiveEdge = edge.prevActiveEdge;
        }
        if (edge.prevActiveEdge != null) {
            edge.prevActiveEdge.nextActiveEdge = edge.nextActiveEdge;
        } else {
            firstActiveEdge = edge.nextActiveEdge;
        }
    }

    private void processStartList(int z) {
        for (Edge edge : startLists[z - ZMIN]) {
            addToActiveEdges(edge);
        }
    }

    private void processEndList(int z) {
        for (Edge edge : endLists[z - ZMIN]) {
            removeFromActiveEdges(edge);
        }
    }

    private void populateCandidates(int z) {
        candidates.clear();

        Edge edge = firstActiveEdge;
        while (edge != null) {
            double lambda = 1.0 * (z - edge.p1.z) / (edge.p2.z - edge.p1.z);
            Candidate2d candidate = new Candidate2d(
                    edge.p1.x + lambda * (edge.p2.x - edge.p1.x),
                    edge.p1.y + lambda * (edge.p2.y - edge.p1.y),
                    edge);
            candidates.add(candidate);
            edge = edge.nextActiveEdge;
        }

        for (Point3d point : points) {
            if (point.z == z) {
                Candidate2d candidate = new Candidate2d(point.x,  point.y, null);
                candidates.add(candidate);
            }
        }
    }

    private double sine(Candidate2d a, Candidate2d b, Candidate2d c) {
        double dx1 = b.x - a.x;
        double dy1 = b.y - a.y;
        double dx2 = c.x - a.x;
        double dy2 = c.y - a.y;
        double l1 = Math.hypot(dx1, dy1);
        double l2 = Math.hypot(dx2, dy2);
        if (l1 < EPSILON || l2 < EPSILON) {
            return 0;
        }
        return (dx1 * dy2 - dx2 * dy1) / (l1 * l2);
    }

    private double buildConvexHull() {
        if (candidates.size() < 3) {
            return 0;
        }

        Candidate2d origin = candidates.get(0);
        for (Candidate2d candidate : candidates) {
            if (candidate.x < origin.x || candidate.x == origin.x && candidate.y < origin.y) {
                origin = candidate;
            }
        }
        candidates.remove(origin);

        final Candidate2d finalOrigin = origin;
        Collections.sort(candidates, new Comparator<Candidate2d>() {
            public int compare(Candidate2d lhs, Candidate2d rhs) {
                if (lhs == rhs)
                    return 0;
                double s = sine(finalOrigin, lhs, rhs);
                if (s > EPSILON) {
                    return -1;
                } else if (s < -EPSILON) {
                    return 1;
                } else {
                    return Math.hypot(lhs.x - finalOrigin.x, lhs.y - finalOrigin.y) < Math.hypot(rhs.x - finalOrigin.x, rhs.y - finalOrigin.y) ? -1 : 1;
                }
            }
        });

        ArrayList<Candidate2d> convexHull = new ArrayList<Candidate2d>();
        convexHull.add(origin);
        for (Candidate2d candidate : candidates) {
            int size = convexHull.size();
            while (size > 1 && sine(convexHull.get(size - 2), convexHull.get(size - 1), candidate) < EPSILON) {
                size--;
                convexHull.remove(size);
            }
            convexHull.add(candidate);
        }

        for (Candidate2d candidate :  candidates) {
            candidate.used = false;
        }

        for (Candidate2d candidate : convexHull) {
            candidate.used = true;
        }

        for (Candidate2d candidate :  candidates) {
            if (!candidate.used && candidate.edge != null) {
                removeFromActiveEdges(candidate.edge);
            }
        }

        double result = 0;
        convexHull.add(origin);
        for (int i = 0; i < convexHull.size() - 1; i++) {
            Candidate2d p1 = convexHull.get(i);
            Candidate2d p2 = convexHull.get(i + 1);
            result += p1.x * p2.y - p1.y * p2.x;
        }

        return Math.abs(result) / 2;
    }

    private void run() throws FileNotFoundException {
        Locale.setDefault(Locale.US);
        Scanner in = new Scanner(new File("aerodynamics.in"));
        int n = in.nextInt();
        int zmin = in.nextInt();
        int zmax = in.nextInt();
        points = new Point3d[n];
        for (int i = 0; i < n; i++) {
            int x = in.nextInt();
            int y = in.nextInt();
            int z = in.nextInt();
            points[i] = new Point3d(x, y, z);
        }
        in.close();

        populateEdges();

        PrintWriter out = new PrintWriter("aerodynamics.out");
        for (int z = ZMIN; z <= ZMAX; z++) {
            processStartList(z);
            if (z >= zmin && z <= zmax) {
                populateCandidates(z);
                double area = buildConvexHull();
                out.printf("%.10f\n", area);
            }
            processEndList(z);
        }
        out.close();
    }
}
