#include <iostream>
#include <iomanip>
#include <cmath>
using namespace std;

template<typename T>
inline T sqr(T x)
{
    return x * x;
}

const double eps = 1e-9;

const int kMaxItr = 1000;

struct Point
{
    double x, y;

    Point() :
        x(0.0),
        y(0.0)
    {
    }

    Point(double x, double y) :
        x(x),
        y(y)
    {
    }

};

double Length(const Point& point)
{
    return sqrt(sqr(point.x) + sqr(point.y));
}

void Normalize(Point& point)
{
    double len = Length(point);

    point.x /= len;
    point.y /= len;
}

istream& operator >> (istream& input_stream, Point& point)
{
    input_stream >> point.x >> point.y;
    return input_stream;
}

Point operator - (const Point& lhs, const Point& rhs)
{
    return Point(lhs.x - rhs.x, lhs.y - rhs.y);
}

double VMult(const Point& lhs, const Point& rhs)
{
    return lhs.x * rhs.y - lhs.y * rhs.x;
}

double SMult(const Point& lhs, const Point& rhs)
{
    return lhs.x * rhs.x + lhs.y * rhs.y;
}

Point operator + (const Point& lhs, const Point& rhs)
{
    return Point(lhs.x + rhs.x, lhs.y + rhs.y);
}

Point operator * (double d, const Point& point)
{
    return Point(point.x * d, point.y * d);
}

struct Line
{
    double A;
    double B;
    double C;

    Line(const Point& P1, const Point& P2)
    {
        A = P1.y - P2.y;
        B = P2.x - P1.x;
        C = -(P1.x * A + P1.y * B);
    }

    double operator () (const Point& P) const
    {
        return P.x * A + P.y * B + C;
    }
};

Point GetIntersection(const Point& P1, const Point& P2,
                    const Point& Q1, const Point& Q2)
{
    Line L1(P1, P2);
    Line L2(Q1, Q2);

    double delta = L1.A * L2.B - L1.B * L2.A;

    double delta_x = (-L1.C) * L2.B - L1.B * (-L2.C);

    double delta_y = L1.A * (-L2.C) - (-L1.C) * (L2.A);

    return Point(delta_x / delta, delta_y / delta);
}

double GetDist(const Point& P1, const Point& P2)
{
    return Length(P2 - P1);
}

bool IsOnSegment(const Point& P, const Point& A, const Point& B)
{
    return SMult(P - A, B - A) + eps > 0 &&
            SMult(P - B, A - B) + eps > 0;
}

double GetTriangleSquare(const Point& P1, const Point& P2, const Point& P3)
{
    return fabs(VMult(P2 - P1, P3 - P1)) / 2.0;
}

ostream& operator << (ostream& output_stream, const Point& point)
{
    output_stream << "(" << point.x << ", " << point.y << ")";
    return output_stream;
}

bool IsOnLine(const Point& P, const Point& A, const Point& B)
{
    Line L(A, B);

    return fabs(L(P)) < eps;
}

bool IsOnSegmentLine(const Point& P, const Point& A, const Point& B)
{
    return IsOnSegment(P, A, B) &&
            IsOnLine(P, A, B);
}

double SolveTask(Point A, Point B, Point C,
                    Point FS, Point FF, int itr)
{
    if (itr == 0) {
        return 0.0;
    }

    Point P1 = C - A;
    Normalize(P1);

    Point P2 = B - A;

    double dist1 = SMult(P2, P1);

    Point Bn = A + dist1 * P1;

    double square = GetTriangleSquare(A, B, C);

    if (IsOnLine(FF, A, B)) {
        if (IsOnLine(FS, A, B)) {
            return 0.0;
        } else {
            return square;
        }
    }

    if (IsOnLine(FF, A, C)) {
        if (IsOnLine(FS, A, C)) {
            return 0.0;
        } else {
            return square;
        }
    }

    if (IsOnLine(FF, B, C)) {
        if (IsOnLine(FS, B, C)) {
            return 0.0;
        } else {
            return square;
        }
    }

    Point O = GetIntersection(FS, FF, Bn, B);

    double result = 0.0;

    bool is_on_segment = false;
    if (IsOnSegment(O, FS, FF)) {
        is_on_segment = true;
        result += square / 2.0;
    }

    if (VMult(C - B, Bn - B) < 0) {
        swap(A, C);
    }

    if (fabs(VMult(FF - B, Bn - B)) < eps) {
        return result;
    }

    if (VMult(FF - B, Bn - B) > 0) {
        if (is_on_segment) {
            result += SolveTask(C, Bn, B, O, FF, itr - 1);
        } else {
            result += SolveTask(C, Bn, B, FS, FF, itr - 1);
        }
    } else {
        if (is_on_segment) {
            result += SolveTask(A, Bn, B, O, FF, itr - 1);
        } else {
            result += SolveTask(A, Bn, B, FS, FF, itr - 1);
        }
    }

    return result;
}

int main()
{
    cout << fixed << setprecision(15);
    ios_base::sync_with_stdio(false);

    Point F;

    cin >> F;

    cout << SolveTask(Point(0.0, 0.0), Point(10.0, 0.0), Point(10.0, 10.0),
                        Point(0.0, 0.0), F, kMaxItr) << endl;

    return 0;
}
