#include <iostream>
#include <cassert>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <complex>
using namespace std;

typedef complex<double> point;
typedef vector<point> polygon;

template <class T> int size(const T &x) { return x.size(); }

const double EPS = 1e-9;

double dot(point a, point b) {
    return real(conj(a) * b);
}
double cross(point a, point b) {
    return imag(conj(a) * b);
}

double ccw(point a, point b, point c) {
    return cross(b - a, c - b);
}

double polygon_area_signed(polygon p) {
    double area = 0;
    int cnt = p.size();
    for (int i = 1; i + 1 < cnt; i++) {
        area += cross(p[i] - p[0], p[i+1] - p[0]);
    }
    return area/2.0;
}
double polygon_area(polygon p) {
    return abs(polygon_area_signed(p));
}

#define MAXN 1000
point hull[MAXN];
bool cmp(const point &a, const point &b) {
    return abs(real(a) - real(b)) > EPS ? real(a) < real(b) : imag(a) < imag(b);
}

int convex_hull(polygon p) {
    int n = size(p), l = 0;
    sort(p.begin(), p.end(), cmp);
    for (int i = 0; i < n; i++) {
        if (i > 0 && p[i] == p[i-1]) continue;
        while (l >= 2 && ccw(hull[l-2], hull[l-1], p[i]) >= 0) l--;
        hull[l++] = p[i];
    }
    int r = l;
    for (int i = n - 2; i >= 0; i--) {
        if (p[i] == p[i+1]) continue;
        while (r - l >= 1 && ccw(hull[r-2], hull[r-1], p[i]) >= 0) r--;
        hull[r++] = p[i];
    }
    return l == 1 ? 1 : r - 1;
}

struct Point {
    double x, y, z;
    Point() {
         }
    Point(double x, double y, double z) : x(x), y(y), z(z) {
    }

    Point(const Point& rhs){
        x = rhs.x;
        y = rhs.y;
        z = rhs.z;
    }

    Point operator *(double k) const {
        return Point(k * x, k * y, k * z);
    }
    Point operator /(double k) const {
        return Point(x / k, y / k, z / k);
    }
    double operator %(const Point &p) const {
        return x * p.x + y * p.y + z * p.z;
    }
    Point operator *(const Point &p) const {
        return Point(
                    y * p.z - z * p.y,
                    z * p.x - x * p.z,
                    x * p.y - y * p.x
                );
    }
    Point operator +(const Point &p) const {
        return Point(
                x + p.x,
                y + p.y,
                z + p.z
                );
    }
    Point operator -(const Point &p) const {
        return Point(
                x - p.x,
                y - p.y,
                z - p.z
                );
    }

    double distTo(const Point & p) const {
        return (*this - p).length();
    }

    double length() const {
        return sqrt(*this % *this);
    }
};

int getIntersection(
        Point &a,
        Point &b,

        Point &c, 
        Point &d,
        Point &e,

        Point &o) {

    Point v = b - a;
    double V1 = (c - a) * (d - a) % (e - a);
    double V2 = (d - b) * (c - b) % (e - b);
    double V = V1 + V2;
    assert(abs(V) > EPS);
    v = v / V;
    /*
    if (abs(V - 0.0) < EPS) {
        if (a.isOnPlane(c, d, e)) return 2;
        return 0;
    }
    */
    v = v * V1;
    o = a + v;
    return 1;
}

vector<point> pts[110];

int main() {

    double m, h, H;

    double x, y;

    scanf("%lf %lf %lf\n", &m, &h, &H);
    // printf("%lf %lf %lf\n", m, h, H);

    vector<Point> points;

    for(int i = 0; i < 4; ++i){
        scanf("%lf %lf\n", &x, &y);

        points.push_back(Point(x, y, 0));
    }

    scanf("%lf %lf\n", &x, &y);
    points.push_back(Point(x, y, H));

    Point center(points[0].x, points[0].y, h);

    // for(int i = 0; i < 5; ++i){
    //     printf("%lf %lf %lf\n", points[i].x, points[i].y, points[i].z);
    // }

    //printf("Sphere center: %lf %lf %lf\n\n", center.x, center.y, center.z);


    bool touch = false;
    // points[1], points[2], points[3]
    Point n = ((points[2] - points[1]) * (points[3] - points[1]));
    Point A = center + (n * 100.0);
    Point B = center - (n * 100.0);
    Point intersect;
    getIntersection(
            A, B,
            points[1], points[2], points[3],
            intersect);
    if(intersect.distTo(center) - (m - h) < 1e-9 ){
        touch = true;
    }

    // points[1], points[2], points[4]
    n  = ((points[2] - points[1]) * (points[4] - points[1]));
    A = center + (n * 100.0);
    B = center - (n * 100.0);
    getIntersection(
            A, B,
            points[1], points[2], points[4],
            intersect);
    if(intersect.distTo(center) - (m - h) < 1e-9 ){
        touch = true;
    }

    // points[2], points[3], points[4]
    n  = ((points[3] - points[2]) * (points[4] - points[2]));
    A = center + (n * 100.0);
    B = center - (n * 100.0);
    getIntersection(
            A, B,
            points[2], points[3], points[4],
            intersect);
    if(intersect.distTo(center) - (m - h) < 1e-9 ){
        touch = true;
    }

    // points[1], points[3], points[4]
    n  = ((points[3] - points[1]) * (points[4] - points[1]));
    A = center + (n * 100.0);
    B = center - (n * 100.0);
    getIntersection(
            A, B,
            points[1], points[3], points[4],
            intersect);
    if(intersect.distTo(center) - (m - h) < 1e-9 ){
        touch = true;
    }

    if(touch){
        printf("YES\n");
    } else {
        printf("NO\n");
    }
}


