#include <iostream>
#include <cassert>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <complex>
using namespace std;

typedef complex<double> point;
typedef complex<double> zoint;
typedef vector<point> polygon;

template <class T> int size(const T &x) { return x.size(); }

const double EPS = 1e-9;

double dot(point a, point b) {
    return real(conj(a) * b);
}
double cross(point a, point b) {
    return imag(conj(a) * b);
}

double ccw(point a, point b, point c) {
    return cross(b - a, c - b);
}

double polygon_area_signed(polygon p) {
    double area = 0;
    int cnt = p.size();
    for (int i = 1; i + 1 < cnt; i++) {
        area += cross(p[i] - p[0], p[i+1] - p[0]);
    }
    return area/2.0;
}
double polygon_area(polygon p) {
    return abs(polygon_area_signed(p));
}

#define MAXN 1000
point hull[MAXN];
bool cmp(const point &a, const point &b) {
    return abs(real(a) - real(b)) > EPS ? real(a) < real(b) : imag(a) < imag(b);
}

int convex_hull(polygon p) {
    int n = size(p), l = 0;
    sort(p.begin(), p.end(), cmp);
    for (int i = 0; i < n; i++) {
        if (i > 0 && p[i] == p[i-1]) continue;
        while (l >= 2 && ccw(hull[l-2], hull[l-1], p[i]) >= 0) l--;
        hull[l++] = p[i];
    }
    int r = l;
    for (int i = n - 2; i >= 0; i--) {
        if (p[i] == p[i+1]) continue;
        while (r - l >= 1 && ccw(hull[r-2], hull[r-1], p[i]) >= 0) r--;
        hull[r++] = p[i];
    }
    return l == 1 ? 1 : r - 1;
}

bool intersect(point a, point b, point p, point q, bool segment= true) {
    point r = b - a, s = q - p;
    double c = cross(r, s), t = cross(p - a, s) / c, u = cross(p - a, r) / c;
    if(segment && (t < 0 - EPS || t > 1 + EPS || u < 0 - EPS || u > 1 + EPS))
        return false;
    //res = a + t * r;
    return true;
}

double triangle_area(point A, point B, point C) {
    return abs(cross(B - A, C - A) / 2.0);
}

bool triangle_contains(point A, point B, point C, point X) {
    double area  = 0.0;
    area += triangle_area(A, B, X);
    area += triangle_area(A, X, C);
    area += triangle_area(X, B, C);
    return abs(area - triangle_area(A, B, C)) < 1e-9;
}

bool line_contains(point A, point B, point X)
{
    return abs(cross(A - X, B - X)) < EPS;
}


int main() {
    double x, y;
    scanf("%lf %lf", &x, &y);

    point main(x, y);
    //printf("%lf %lf\n", real(main), imag(main));

    point p0(10, 10), p1(0,0), p2(10, 0);
    double size = cross((p2 - p1), (p0 - p1))/2.0;
    double total = 0.0;

    while(size > 1e-8) {
        //printf("%(%lf, %lf)(%lf, %lf)(%lf, %lf)\n", real(p0), imag(p0),real(p1), imag(p1),real(p2), imag(p2));
        point split = (p1 + p0) / 2.0;
        //printf("split: %lf %lf\n", real(split), imag(split));
        size /= 2.0;
        // printf("size: %lf\n", size);
        // printf("total; %lf\n", total);
        
        // int linters = 0,
        //     rinters = 0;

        /*
        if(intersect(p1, p2, point(0,0), main)) {
            rinters ++;
        }
        if(intersect(p1, split, point(0,0), main)) {
            rinters ++;
        }
        */
        if(intersect(split, p2, point(0,0), main)) {
            // rinters ++;
            // linters ++;
            if(line_contains(split, p2, main)) {
                total += size;
                // printf("The split line contains point\n");
                // printf("%lf %lf -> %lf %lf contains %lf %lf\n", real(split), imag(split), real(p2), imag(p2), real(main), imag(main));
                break;
            }
            if(intersect(p1, p2, point(0,0), main) || 
               intersect(p1, split, point(0,0), main) ||
               intersect(p0, p2, point(0,0), main) ||
               intersect(split, p0, point(0,0), main)) {

                total += size;
            }
        }
        /*
        if(intersect(p0, p2, point(0,0), main)) {
            linters ++;
        }
        if(intersect(split, p0, point(0,0), main)) {
            rinters ++;
        }
        */


        if(triangle_contains(p1, p2, split, main)){
            p0 = p1;
            p1 = p2;
            p2 = split;
        } else if(triangle_contains(p0, p2, split, main)) {
            p1 = p0;
            p0 = p2;
            p2 = split;
        } else {
            assert(false);
            break;
        }
    }

    printf("%lf\n", total);

    return 0;
}


